@@ -1,5 +1,5 @@
 /* font-ft.c -- FreeType interface sub-module.
-   Copyright (C) 2003, 2004, 2005, 2006, 2007, 2008, 2009, 2010
+   Copyright (C) 2003, 2004, 2005, 2006, 2007, 2008, 2009, 2010, 2011, 2012
      National Institute of Advanced Industrial Science and Technology (AIST)
      Registration Number H15PRO112
 
@@ -371,11 +371,12 @@ fc_decode_prop (int val, FC_vs_M17N_font_prop *table, int size)
 	  break;
       i++;
     }
-  else
+  else if (val > table[i].fc_value)
     {
-      for (; i < size; i++)
-	if (val <= table[i].fc_value)
+      for (i++; i < size; i++)
+	if (val < table[i].fc_value)
 	  break;
+      i--;
     }
   return table[i].sym;
 }
