@@ -1177,15 +1177,15 @@ enum MInputCandidatesChanged
 
 struct MInputContext
 {
-  /***en Backward pointer to the input method.  It is set up be the
+  /***en Backward pointer to the input method.  It is set up by the
       function minput_create_ic ().  */
   /***ja ϥ᥽åɤؤεեݥ󥿡ؿ minput_create_ic () 
       ˤäꤵ롣  */ 
   MInputMethod *im;
 
   /***en M-text produced by the input method.  It is set up by the
-      function minput_lookup () .  */
-  /***ja ϥ᥽åɤˤä M-textؿ minput_lookup () 
+      function minput_filter () .  */
+  /***ja ϥ᥽åɤˤä M-textؿ minput_filter () 
       ˤäꤵ롣  */
   MText *produced;
 
@@ -1389,6 +1389,8 @@ extern MPlist *minput_get_variables (MSymbol language, MSymbol name);
 extern int minput_set_variable (MSymbol language, MSymbol name,
 				MSymbol variable, void *value);
 
+extern MPlist *minput_parse_im_names (MText *mt);
+
 extern MPlist *minput_list (MSymbol lang);
 
 extern MInputMethod *mdebug_dump_im (MInputMethod *im, int indent);
