@@ -1,5 +1,5 @@
 /* mtext.c -- M-text module.
-   Copyright (C) 2003, 2004, 2005, 2006, 2007, 2008, 2009, 2010
+   Copyright (C) 2003, 2004, 2005, 2006, 2007, 2008, 2009, 2010, 2011, 2012
      National Institute of Advanced Industrial Science and Technology (AIST)
      Registration Number H15PRO112
 
@@ -283,11 +283,13 @@ insert (MText *mt1, int pos, MText *mt2, int from, int to)
       if (total_bytes + unit_bytes > mt1->allocated)
 	{
 	  mt1->allocated = total_bytes + unit_bytes;
-	  MTABLE_REALLOC (mt1->data, mt1->allocated, MERROR_MTEXT);
+	  if (mt1->data)
+	    MTABLE_REALLOC (mt1->data, mt1->allocated, MERROR_MTEXT);
+	  else
+	    MTABLE_CALLOC (mt1->data, mt1->allocated, MERROR_MTEXT);
 	}
-      if (pos < mt1->nchars)
-	memmove (mt1->data + pos_byte + new_bytes, mt1->data + pos_byte,
-		 (mt1->nbytes - pos_unit + 1) * unit_bytes);
+      memmove (mt1->data + pos_byte + new_bytes, mt1->data + pos_byte,
+	       (mt1->nbytes - pos_unit + 1) * unit_bytes);
       memcpy (mt1->data + pos_byte, mt2->data + from_unit * unit_bytes,
 	      new_bytes);
     }
@@ -1841,7 +1843,7 @@ mtext_ref_char (MText *mt, int pos)
       if (mt->format != MTEXT_FORMAT_UTF_16)
 	{
 	  p1[0] = SWAP_16 (*p);
-	  if (p1[0] >= 0xD800 || p1[0] < 0xDC00)
+	  if (p1[0] >= 0xD800 && p1[0] < 0xDC00)
 	    p1[1] = SWAP_16 (p[1]);
 	  p = p1;
 	}
