@@ -1,5 +1,5 @@
 /* plist.c -- plist module.
-   Copyright (C) 2003, 2004, 2005, 2006, 2007, 2008, 2009, 2010
+   Copyright (C) 2003, 2004, 2005, 2006, 2007, 2008, 2009, 2010, 2011, 2012
      National Institute of Advanced Industrial Science and Technology (AIST)
      Registration Number H15PRO112
 
@@ -266,7 +266,7 @@ read_mtext_element (MPlist *plist, MStream *st, int skip)
 
       if (! skip)
 	{
-	  if (i + MAX_UTF8_CHAR_BYTES >= nbytes)
+	  if (i + MAX_UTF8_CHAR_BYTES + 1 >= nbytes)
 	    {
 	      if (buf == buffer)
 		{
@@ -290,8 +290,10 @@ read_mtext_element (MPlist *plist, MStream *st, int skip)
 
   if (! skip)
     {
-      MText *mt = mtext__from_data (buf, i, MTEXT_FORMAT_UTF_8,
-				    (buf == buffer));
+      MText *mt;
+
+      buf[i] = 0;
+      mt = mtext__from_data (buf, i, MTEXT_FORMAT_UTF_8, (buf == buffer));
       if (buf != buffer)
 	mt->allocated = nbytes;
       MPLIST_SET_ADVANCE (plist, Mtext, mt);
